__version__ = '1.2.4'

__title__ = 'noora'
__description__ = 'NoOra a database deployment tool.'
__uri__ = 'https://github.com/janripke/noora'
__doc__ = __description__ + ' <' + __uri__ + '>'

__author__ = 'Jan Ripke'
__email__ = 'janripke@gmail.com'

__license__ = 'Apache License 2.0'
__copyright__ = 'Copyleft (l) 2021 Jan Ripke'

